div.admonition {
    transition: width 0.5s;
    -webkit-transition: width 0.5s;
    overflow: hidden;
}

div.admonition:active {
    width: 150%
}

div.note:active {
    width: 100%
}

div.highlight-yaml {
    transition: width 0.5s;
    -webkit-transition: width 0.5s;
    overflow: hidden;
}

div.highlight-yaml:active {
    width: 150%
}

div.highlight-default {
    transition: width 0.5s;
    -webkit-transition: width 0.5s;
    overflow: hidden;
}

div.highlight-default:active {
    width: 150%
}

div.highlight-python {
    transition: width 0.5s;
    -webkit-transition: width 0.5s;
    overflow: hidden;
}

div.highlight-python:active {
    width: 150%
}

/* Top Banner Navigation
-------------------------------------------------- */
.announcement-content a {
    padding-right: 1em;
  }

.announcement-content a:hover {
  color: fuchsia;
}
